@@ -1,4 +1,4 @@
-# $Id: FileTransfer.pm 8251 2013-09-02 07:48:52Z hurko $
+# $Id: FileTransfer.pm 8986 2014-04-28 05:55:13Z hurko $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/libuvt-noc-perl/lib/UvT/NOC/FileTransfer.pm $
 
 use utf8;
@@ -179,12 +179,19 @@ sub downloadFileUsingHTTPS
 		my $realm = $resource->getProperty('realm')->value;
 		my $username = $resource->getProperty('username')->value;
 		my $password = $resource->getProperty('password')->value;
+		my $ssl_opts = $resource->getProperty('ssl_opts') ? $resource->getProperty('ssl_opts')->value : undef;
 
 		$ENV{HTTPS_DEBUG} = $debug;
 
 		my $useragent = LWP::UserAgent->new();
-		# enforce SSLv3 voor brakke Oracle-SSL op uvtapp.uvt.nl
-		$useragent->ssl_opts( SSL_version => "SSLv3");
+
+		# enforce ssl options (bv voor SSLv3 voor brakke Oracle-SSL op uvtapp.uvt.nl)
+		if ($ssl_opts)
+		{
+			if ($debug) { warn "Set SSL opts : $ssl_opts\n"; }
+			$useragent->ssl_opts( SSL_version => $ssl_opts);
+		}
+
 		$useragent->credentials($host . ":" . $port, $realm, $username, $password);
 		my $request = HTTP::Request->new(GET => "$url");
 		my $response = $useragent->request($request);
